import unittest
from paab.policy.tests.base import PaabPolicyTestCase
from Products.CMFCore.utils import getToolByName
from Products.CMFPlone.utils import _createObjectByType 

class TestSetup(PaabPolicyTestCase):

    def test_portal_title(self):
        self.assertEquals("Paab", self.portal.getProperty('title'))
        
    def test_portal_description(self):
        self.assertEquals("Welcome to paab", self.portal.getProperty('description'))

    def test_homeTopicDefault(self):
        """test if there's a topic in home called blog and is the default's root folder's display and it's published"""
        blog = self.portal.blog
        self.assertEquals("ATTopic" , blog.meta_type)
        self.assertEquals("blog" , blog.id)
        self.assertEquals("blog" , self.portal.defaultView())

        workflowTool = getToolByName(self.portal, "portal_workflow")
        status = workflowTool.getStatusOf("simple_publication_workflow", blog)
        self.assertEquals("published" , status['review_state'])

    def test_homeCriteria(self):
        """the criteria of the collection should be just news """
        blog = self.portal.blog
        criteria = blog.crit__Type_ATPortalTypeCriterion
        self.assertEquals( u'Type'  , criteria.field )
        self.assertEquals( (u'News Item',)  , criteria.value )

    def test_homeNewsWorkflow(self):
        """the collection should show just published content """
        blog = self.portal.blog
        criteria = blog.crit__review_state_ATSimpleStringCriterion
        self.assertEquals( u'published'  , criteria.value )

    def test_homeNewsSortOrder(self):
        """the collection should show just published content """
        blog = self.portal.blog
        criteria = blog.crit__effective_ATSortCriterion 
        self.assertEquals( True  , criteria.reversed )
        self.assertEquals( u'effective' , criteria.field )

    def test_homeContent(self):
        """after adding silly news on home and other folder, does the collection show them"""
        self.setRoles(('Manager',))

        blog = self.portal.blog
        q1 = blog.queryCatalog(batch=True)

        # I create a news item and i publish it
        self.portal.invokeFactory("News Item", "n1", title= 'n1', description='')         
        n1 = self.portal.n1
        wftool = getToolByName(self.portal, "portal_workflow")
        status = wftool.getStatusOf("simple_publication_workflow", n1)
        if status['review_state'] != 'published':
            wftool.doActionFor(n1, 'publish', 'simple_publication_workflow')

        #is it on the collection ?
        q2 = blog.queryCatalog(batch=True)
        self.assertEquals( q1.length + 1 , q2.length )
        

def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestSetup))
    return suite
